//
//  CameraNativeView.swift
//  Pods
//
//  Created by Sarbjyot Chahal on 31.03.22.
//

import Foundation
import Flutter
import ScanbotSDK
class CameraNativeView : NSObject, FlutterPlatformView, CallErrorHandler {
    
    private let kViewControllerAppearDelay = 0.2
    private var cintainerView: UIView
    private let configuration : [String: Any?]?
    private var cameraMethodChannel: FlutterMethodChannel?
    private let detectorChannel: FlutterMethodChannel?
    private let finderChannel: FlutterMethodChannel?

    private var scanner: SBSDKScanner?
    
    init(
        frame: CGRect,
        viewIdentifier viewId: Int64,
        arguments args: Any?,
        binaryMessenger messenger: FlutterBinaryMessenger
    ) {
        
        detectorChannel = FlutterMethodChannel(name: "scanbot_sdk_camera.detector_\(viewId)", binaryMessenger:  messenger)
        cameraMethodChannel = FlutterMethodChannel(name: "scanbot_sdk_camera_\(viewId)", binaryMessenger:  messenger)
        finderChannel = FlutterMethodChannel(name: MethodChannelConstants.kClassicalCameraFinderChannel, binaryMessenger:  messenger)
        
        cintainerView = UIView()
        configuration = args as? [String:Any?]
      
        switch configuration!["detectorType"] as? String {
        case "barcode" :
            scanner = BarcodeScanner(cameraMethodChannel: cameraMethodChannel, detectorChannel: detectorChannel, finderChannel: finderChannel, configuration: configuration!)
        case "document" :
            scanner = DocumentScanner(cameraMethodChannel: cameraMethodChannel, detectorChannel: detectorChannel, finderChannel: finderChannel, configuration: configuration!)
        default: break
        }

        super.init()
        
        DispatchQueue.main.asyncAfter(deadline: .now() + kViewControllerAppearDelay) { [weak self] in
            guard let _containerView = self?.cintainerView else {
                return
            }
            self?.scanner?.attach(view: _containerView)
        
            self?.cameraMethodChannel?.setMethodCallHandler({
                (call: FlutterMethodCall, result: @escaping FlutterResult) -> Void in
                self?.handleCameraCall(call: call, result: result)
            })
        }
    }
    
    func view() -> UIView {
        return cintainerView
    }
    
    
    fileprivate func toggleFlash(arguments : [String:Any?]?) {
        if let flashEnabled = arguments?["enabled"] as? Bool {
            self.scanner?.setFlash(enabled: flashEnabled)
        }
    }
    
    fileprivate func isFlashAvailable(result: @escaping FlutterResult) {
        result(self.scanner?.isFlashAvailable())
    }
    
    func handleCameraCall(call: FlutterMethodCall, result: @escaping FlutterResult) {
        let arguments = call.arguments as? [String:Any?]
        switch call.method {
        case "flashEnabled" : toggleFlash(arguments: arguments)
        case "isFlashAvailable" : isFlashAvailable(result: result)
         return
        case "dispose" : self.scanner?.detach()
        default:
            self.returnUnknownCallError(call: call, result: result)
            return
        }
        resurnSuccess(result: result)
    }
    
    func resurnSuccess(result: @escaping FlutterResult){
        result("success")
    }
}
