//
//  SBSDKUIMachineCodeScannerBehaviorConfiguration.swift
//  scanbot_sdk
//
//  Created by Zhenya Knizhnik on 26.08.19.
//

import Foundation
import ScanbotSDK

extension SBSDKUIBarcodeScannerBehaviorConfiguration {
    convenience init(from dictionary: [String: Any]) {
        self.init()
        
        if let flashEnabled = dictionary["flashEnabled"] as? Bool {
            self.isFlashEnabled = flashEnabled
        }
        
        if let autoCancelTimeout = dictionary["autoCancelTimeout"] as? Double {
            self.autoCancelTimeout = autoCancelTimeout
        }
        
        if let successBeepEnabled = dictionary["successBeepEnabled"] as? Bool {
            self.isSuccessBeepEnabled = successBeepEnabled
        }
        
        if let value = dictionary["barcodeImageGenerationType"] as? String {
            let barcodeImageGenerationType = SBSDKBarcodeImageGenerationType(from: value)
            self.barcodeImageGenerationType = barcodeImageGenerationType
        }
        
        if let value = dictionary["additionalParameters"] as? [String: Any] {
            let barcodeImageGenerationType = SBSDKBarcodeAdditionalParameters(from: value)
            self.additionalParameters = barcodeImageGenerationType
        }
        
        if let value = dictionary["gs1DecodingEnabled"] as? Bool {
            self.additionalParameters.enableGS1Decoding = value
        }
        
        if let value = dictionary["minimumTextLength"] as? UInt {
            self.additionalParameters.minimumTextLength = value
        }
        
        if let value = dictionary["maximumTextLength"] as? UInt {
            self.additionalParameters.maximumTextLength = value
        }
        
        if let value = dictionary["minimum1DBarcodesQuietZone"] as? UInt {
            self.additionalParameters.minimum1DBarcodesQuietZone = value
        }
        
        if let value = dictionary["msiPlesseyChecksumAlgorithm"] as? String {
            self.additionalParameters.msiPlesseyChecksumAlgorithm = SBSDKBarcodeMSIPlesseyChecksumAlgorithm(from: value)
        }
        
        if let value = dictionary["stripCheckDigits"] as? Bool {
            self.additionalParameters.stripCheckDigits = value
        }
        
        if let engineMode = SBSDKBarcodeEngineMode.fromArguments(dictionary) {
            self.engineMode = engineMode
        }
        
        if let cameraZoomFactor = dictionary["cameraZoomFactor"] as? CGFloat {
            self.cameraZoomFactor = cameraZoomFactor
        }
        
        if let focusLockEnabled = dictionary["minFocusDistanceLock"] as? Bool {
            self.isFocusLockEnabled = focusLockEnabled
        }
        
        if dictionary["barcodeFormats"] is [String] {
            self.acceptedMachineCodeTypes = SBSDKBarcodeType.fromArguments(dictionary) ?? []
        }
        
        if dictionary["acceptedDocumentFormats"] is [String] {
            self.acceptedDocumentTypes = SBSDKBarcodeDocumentType.fromArguments(dictionary) ?? []
        }
        
    }
}

extension SBSDKUIMRZScannerBehaviorConfiguration {
    convenience init(from dictionary: [String: Any]) {
        self.init()
        
        if let flashEnabled = dictionary["flashEnabled"] as? Bool {
            self.isFlashEnabled = flashEnabled
        }
        
        if let successBeepEnabled = dictionary["successBeepEnabled"] as? Bool {
            self.isSuccessBeepEnabled = successBeepEnabled
        }
    }
}
